import { buildUUID } from '../../../utils/uuid';
import { ApiAction, ApiActionPage } from '../../model/baseModel';
import {
  DeliveryListItem,
  DeliveryePageListGetResultModel,
  DeliveryParams,
  DeliveryPageParams,

  DeliveryDetailPageParams,
  DeliveryeDetailPageListGetResultModel,
  DeliveryDetailSNPageParams,
  DeliveryeDetailSNPageListGetResultModel
} from '../model/warehoueseModel';
import { genAction, Api, genActionPage } from '../system';
import { useUserStore } from '/@/store/modules/user';
import { defHttp } from '/@/utils/http/axios';
import { isNullOrEmpty } from '/@/utils/is';

/*
 * 获取送货单分页列表
 */
export const getDeliveryListByPage = async (params: DeliveryPageParams) => {
  let order = ''
  if (params.order != undefined) {
    order = params.order == 'descend' ? (params.field + ' desc') : params.field
  }
  let sqlcmd = '1=1';
  if (params?.DELIVERY_NO != undefined && params?.DELIVERY_NO != '') {
    sqlcmd += " And DELIVERY_NO like '%" + params?.DELIVERY_NO + "%'";
  }
  // if (params?.ERP_BILL_CODE != undefined && params?.ERP_BILL_CODE != '') {
  //   sqlcmd += " And ERP_BILL_CODE like '%" + params?.ERP_BILL_CODE + "%'";
  // }
  if (params?.RECEIVE_DATE != undefined && params?.RECEIVE_DATE != '') {
    sqlcmd += " And RECEIVE_DATE > '" + params?.RECEIVE_DATE[0] + "'";
  }
  if (params?.RECEIVE_DATE != undefined && params?.RECEIVE_DATE != '') {
    sqlcmd += " And RECEIVE_DATE < '" + params?.RECEIVE_DATE[1] + "'";
  }
  if (params?.STATUS != undefined && params?.STATUS != '') {
    sqlcmd += " And STATUS = '" + params?.STATUS + "'";
  }
  if (params?.PURCHASE_TYPE != undefined && params?.PURCHASE_TYPE != '') {
    sqlcmd += " And PURCHASE_TYPE = '" + params?.PURCHASE_TYPE + "'";
  }
  var option ={
    UserId:useUserStore().getUserInfo.userId as string,
    ByOrg:true,
    OrgCode:useUserStore().getUserInfo.orgCode as string
  }
  if (!isNullOrEmpty(params.page)) {
    const usParams = genAction('BIZ_SRM_DLVY', {
      QueryAble_T: '',
      where: sqlcmd,
      order: order,
      page: {
        pageAble_T: 'string',
        draw: 1,
        pageIndex: params.page,
        pageSize: params.pageSize,
      },
      option
    },option);
    return getDeliveryListByPageAsync(usParams);
  } else {
    const usParams = genAction('BIZ_SRM_DLVY', {
      QueryAble_T: '',
      where: sqlcmd,
      option
    },option);
    return getDeliveryListByPageAsync(usParams);
  }  
  // const rParams = genActionPage('BIZ_SRM_DLVY', sqlcmd, params.page, params.pageSize,option);
  // return getDeliveryListByPageAsync(rParams);
};
async function getDeliveryListByPageAsync(params: any) {
  const data = await defHttp.post(
    { url: Api.QueryUrl, params },
    {
      isTransformResponse: false,
    },
  );
  let model = {}
  if (isNullOrEmpty(data.Data.page)) {
    model = {
      items: data.Data.Items,
    };
  } else {
    model = {
      items: data.Data.page.data,
      total: data.Data.page.totals,
    };
  }
  return model;
}


// 单据详情
export const getDeliveryDetailListByPage = async (params: DeliveryDetailPageParams) => {
  let order = ''
  if (params.order != undefined) {
    order = params.order == 'descend' ? (params.field + ' desc') : params.field
  }
  let sqlcmd = '1=1';
  if (params?.BILLCODE != undefined && params?.BILLCODE != '') {
    sqlcmd += " And DELIVERY_NO = '" + params?.BILLCODE + "'";
  }
  if (params?.ITEM_CODE != undefined && params?.ITEM_CODE != '') {
    sqlcmd += " And ITEM_CODE = '" + params?.ITEM_CODE + "'";
  }
  // if (params?.OUTWAREHOUSECODE != undefined && params?.OUTWAREHOUSECODE != '') {
  //   sqlcmd += " And OUTWAREHOUSECODE = '" + params?.OUTWAREHOUSECODE + "'";
  // }
  // if (params?.INWAREHOUSECODE != undefined && params?.INWAREHOUSECODE != '') {
  //   sqlcmd += " And INWAREHOUSECODE = '" + params?.INWAREHOUSECODE + "'";
  // }
  // if (!isNullOrEmpty(params?.LINESTATUS)) {
  //   sqlcmd += " And STATUS = '" + params?.STATUS + "'";
  // }
  var option ={
    UserId:useUserStore().getUserInfo.userId as string,
    ByOrg:true,
    OrgCode:useUserStore().getUserInfo.orgCode as string
  }
  if (!isNullOrEmpty(params.page)) {
    const usParams = genAction('V_BIZ_SRM_DLVY_DTL', {
      QueryAble_T: '',
      where: sqlcmd,
      order: 'LINE_NO*1 '+order,
      page: {
        pageAble_T: 'string',
        draw: 1,
        pageIndex: params.page,
        pageSize: params.pageSize,
      },
      option
    },option);
    return getDeliveryDetailListByPageAsync(usParams);
  } else {
    const usParams = genAction('V_BIZ_SRM_DLVY_DTL', {
      QueryAble_T: '',
      where: sqlcmd,
      order: 'LINE_NO*1',
      option
    },option);
    return getDeliveryDetailListByPageAsync(usParams);
  }  
  // const rParams = genActionPage('V_BIZ_SRM_DLVY_DTL', sqlcmd, params.page, params.pageSize,option);
  // return getDeliveryDetailListByPageAsync(rParams);
};
async function getDeliveryDetailListByPageAsync(params: any) {
  const data = await defHttp.post(
    { url: Api.QueryUrl, params },
    {
      isTransformResponse: false,
    },
  );
  let model = {}
  if (isNullOrEmpty(data.Data.page)) {
    model = {
      items: data.Data.Items,
    };
  } else {
    model = {
      items: data.Data.page.data,
      total: data.Data.page.totals,
    };
  }
  return model;
}

//条码详情
export const getDeliveryDetailSNListByPage = async (params: DeliveryDetailSNPageParams) => {
  let order = ''
  if (params.order != undefined) {
    order = params.order == 'descend' ? (params.field + ' desc') : params.field
  }
  let sqlcmd = '1=1';
  if (params?.BILLCODE != undefined && params?.BILLCODE != '') {
    sqlcmd += " And DELIVERY_NO = '" + params?.BILLCODE + "'";
  }
  if (params?.ITEM_CODE != undefined && params?.ITEM_CODE != '') {
    sqlcmd += " And ITEM_CODE = '" + params?.ITEM_CODE + "'";
  }
  // if (params?.BUSINESSLINE != undefined && params?.BUSINESSLINE != '') {
  //   sqlcmd += " And BUSINESSLINE = '" + params?.BUSINESSLINE + "'";
  // }
  // if (params?.SN != undefined && params?.SN != '') {
  //   sqlcmd += " And SN = '" + params?.SN + "'";
  // }
  if (!isNullOrEmpty(params?.STATUS)) {
    sqlcmd += " And STATUS = '" + params?.STATUS + "'";
  }
  // if (params?.BILLDATE != undefined && params?.BILLDATE != '') {
  //   sqlcmd += "And BILLDATE like '%" + params?.BILLDATE + "%'";
  // }
  var option ={
    UserId:useUserStore().getUserInfo.userId as string,
    ByOrg:true,
    OrgCode:useUserStore().getUserInfo.orgCode as string
  }
  if (!isNullOrEmpty(params.page)) {
    const usParams = genAction('V_SRM_ITEM', {
      QueryAble_T: '',
      where: sqlcmd,
      order: order,
      page: {
        pageAble_T: 'string',
        draw: 1,
        pageIndex: params.page,
        pageSize: params.pageSize,
      },
      option
    },option);
    return getDeliveryDetailSNListByPageAsync(usParams);
  } else {
    const usParams = genAction('V_SRM_ITEM', {
      QueryAble_T: '',
      where: sqlcmd,
      option
    },option);
    return getDeliveryDetailSNListByPageAsync(usParams);
  }  
  // const rParams = genActionPage('BIZ_SRM_DLVY_SN', sqlcmd, params.page, params.pageSize,option);
  // return getDeliveryDetailSNListByPageAsync(rParams);
};
async function getDeliveryDetailSNListByPageAsync(params: any) {
  const data = await defHttp.post(
    { url: Api.QueryUrl, params },
    {
      isTransformResponse: false,
    },
  );
  let model = {}
  if (isNullOrEmpty(data.Data.page)) {
    model = {
      items: data.Data.Items,
    };
  } else {
    model = {
      items: data.Data.page.data,
      total: data.Data.page.totals,
    };
  }
  return model;
}
// export const SaveEnterWarehouse = async (params: DeliveryListItem, isUpdate: boolean) => {
//   let data;
//   if (isUpdate) {
//     data = await defHttp.post(
//       { url: Api.UpdateEntity, params: genAction('Minsun.WMS_RECEIPT_H', params) },
//       {
//         errorMessageMode: 'none',
//         isTransformResponse: false,
//       },
//     );
//   } else {
//     params.ID = buildUUID(); //生成GUID
//     data = await defHttp.post(
//       { url: Api.AddEntity, params: genAction('Minsun.WMS_RECEIPT_H', params) },
//       {
//         errorMessageMode: 'none',
//         isTransformResponse: false,
//       },
//     );
//   }
//   return data;
// };

// export const DeleteEnterWarehouse = async (params: Recordable) => {
//   const usParams = genAction('Minsun.WMS_RECEIPT_H', [params]);
//   return await defHttp.post(
//     { url: Api.DeleteList, params: usParams },
//     {
//       errorMessageMode: 'none',
//       isTransformResponse: false,
//     },
//   );
// };
//下拉列表
// STATUSs 单据状态
// BIZTYPEs 单据类型
export const optionsListApi = async (params: Recordable) => {
  const usParams = genAction('BIZ_SRM_DLVY+STATUSs', '');
  return await defHttp.post(
    { url: Api.urlQueryEnum, params: usParams },
    {
      errorMessageMode: 'none',
      isTransformResponse: false,
      // apiUrl: globSetting.taskApiUrl
    },
  );
};
//条码状态
export const optionsStatusListApi = async (params: Recordable) => {
  const usParams = genAction('WMS_ITEM+STATUSs', '');
  return await defHttp.post(
    { url: Api.urlQueryEnum, params: usParams },
    {
      errorMessageMode: 'none',
      isTransformResponse: false,
      // apiUrl: globSetting.taskApiUrl
    },
  );
};
export const optionTypeListApi = async (params: Recordable) => {
  const usParams = genAction('BIZ_SRM_DLVY+PURCHASE_TYPEs', '');
  return await defHttp.post(
    { url: Api.urlQueryEnum, params: usParams },
    {
      errorMessageMode: 'none',
      isTransformResponse: false,
      // apiUrl: globSetting.taskApiUrl
    },
  );
};